diff --git a/wp-includes/class-wp-fatal-error-handler.php b/wp-includes/class-wp-fatal-error-handler.php
index f17011cc33..aba6207bae 100644
--- a/wp-includes/class-wp-fatal-error-handler.php
+++ b/wp-includes/class-wp-fatal-error-handler.php
@@ -41,13 +41,15 @@ class WP_Fatal_Error_Handler {
 				load_default_textdomain();
 			}
 
+			$handled = false;
+
 			if ( ! is_multisite() && wp_recovery_mode()->is_initialized() ) {
-				wp_recovery_mode()->handle_error( $error );
+				$handled = wp_recovery_mode()->handle_error( $error );
 			}
 
 			// Display the PHP error template if headers not sent.
 			if ( is_admin() || ! headers_sent() ) {
-				$this->display_error_template( $error );
+				$this->display_error_template( $error, $handled );
 			}
 		} catch ( Exception $e ) {
 			// Catch exceptions and remain silent.
@@ -125,10 +127,12 @@ class WP_Fatal_Error_Handler {
 	 * If no such drop-in is available, this will call {@see WP_Fatal_Error_Handler::display_default_error_template()}.
 	 *
 	 * @since 5.2.0
+	 * @since 5.2.2 The `$handled` parameter was added.
 	 *
 	 * @param array $error Error information retrieved from `error_get_last()`.
 	 */
-	protected function display_error_template( $error ) {
+	protected function display_error_template( $error, $handled ) {
 		if ( defined( 'WP_CONTENT_DIR' ) ) {
 			// Load custom PHP error template, if present.
 			$php_error_pluggable = WP_CONTENT_DIR . '/php-error.php';
@@ -140,7 +144,7 @@ class WP_Fatal_Error_Handler {
 		}
 
 		// Otherwise, display the default error template.
-		$this->display_default_error_template( $error );
+		$this->display_default_error_template( $error, $handled );
 	}
 
 	/**
@@ -153,10 +157,12 @@ class WP_Fatal_Error_Handler {
 	 * be used to modify these parameters.
 	 *
 	 * @since 5.2.0
+	 * @since 5.2.2 The `$handled` parameter was added.
 	 *
 	 * @param array $error Error information retrieved from `error_get_last()`.
 	 */
-	protected function display_default_error_template( $error ) {
+	protected function display_default_error_template( $error, $handled ) {
 		if ( ! function_exists( '__' ) ) {
 			wp_load_translations_early();
 		}
@@ -169,7 +175,9 @@ class WP_Fatal_Error_Handler {
 			require_once ABSPATH . WPINC . '/class-wp-error.php';
 		}
 
-		if ( is_protected_endpoint() ) {
+		if ( true === $handled && wp_is_recovery_mode() ) {
+			$message = __( 'A fatal error was caught by recovery mode. Check the Plugins and/or Themes page for details.' );
+		} elseif ( is_protected_endpoint() ) {
 			$message = __( 'The site is experiencing technical difficulties. Please check your site admin email inbox for instructions.' );
 		} else {
 			$message = __( 'The site is experiencing technical difficulties.' );
@@ -125,10 +127,12 @@ class WP_Fatal_Error_Handler {
 	 *
-	 * @param array $error Error information retrieved from `error_get_last()`.
+	 * @param array         $error   Error information retrieved from `error_get_last()`.
+	 * @param bool|WP_Error $handled Whether Recovery Mode handled the fatal error.
 	 */
@@ -153,10 +157,12 @@ class WP_Fatal_Error_Handler {
 	 *
-	 * @param array $error Error information retrieved from `error_get_last()`.
+	 * @param array         $error   Error information retrieved from `error_get_last()`.
+	 * @param bool|WP_Error $handled Whether Recovery Mode handled the fatal error.
 	 */
